@@ -11,7 +11,8 @@
             [leiningen.core.classpath :as classpath]
             [clojure.string :as str])
   (:import (clojure.lang DynamicClassLoader)
-           (java.io PushbackReader Reader)))
+           (java.io PushbackReader Reader File)
+           (java.util.regex Pattern)))
 
 (defn make-project-properties [project]
   (with-open [baos (java.io.ByteArrayOutputStream.)]
@@ -29,7 +30,9 @@
 (defn- warn [& args]
   ;; TODO: remove with 3.0.0
   (require 'leiningen.core.main)
-  ((resolve 'leiningen.core.main/warn) args))
+  (apply (resolve 'leiningen.core.main/warn) args))
+
+(def ^:private warn-once (memoize warn))
 
 (defn- update-each-contained [m keys f & args]
   (reduce (fn [m k]
@@ -122,6 +125,15 @@
     (with-meta obj m)
     obj))
 
+(defn- vary-meta*
+  "Returns an object of the same type and value as obj, with
+  (apply f (meta obj) args) as its metadata, if the object can hold
+  metadata."
+  [obj f & args]
+  (if (instance? clojure.lang.IObj obj)
+    (apply vary-meta obj f args)
+    obj))
+
 (defn- displace?
   "Returns true if the object is marked as displaceable"
   [obj]
@@ -223,7 +235,8 @@
                                   ["vcs" "commit"]
                                   ["vcs" "push"]]
    :pedantic? (quote ^:top-displace ranges)
-   :jar-exclusions [#"^\."]
+   :jar-exclusions [#"^\." (re-pattern (Pattern/quote (str File/separator ".")))]
+   :eval-in :default
    :offline? (not (nil? (System/getenv "LEIN_OFFLINE")))
    :uberjar-exclusions [#"(?i)^META-INF/[^/]*\.(SF|RSA|DSA)$"]
    :uberjar-merge-with {"META-INF/plexus/components.xml"
@@ -302,6 +315,9 @@
                  :password :gpg :username :gpg}]]
     {:reduce reduce-repo-step}))
 
+(defn- mark-with-replace [obj]
+  (vary-meta* obj assoc :replace true))
+
 (defn normalize-values
   "Transform values within a project or profile map to normalized values, such
   that internal functions can assume that the values are already normalized."
@@ -310,6 +326,7 @@
       (update-each-contained [:repositories :deploy-repositories
                               :mirrors :plugin-repositories] normalize-repos)
       (update-each-contained [:profiles] utils/map-vals normalize-values)
+      (update-each-contained [:aliases] utils/map-vals mark-with-replace)
       (normalize-aot)))
 
 (def ^:private empty-meta-merge-defaults
@@ -388,9 +405,9 @@
              (meta project))))
   ([project]
      (let [repos (if (:omit-default-repositories project)
-                   (do (warn "WARNING:"
-                             ":omit-default-repositories is deprecated;"
-                             "use :repositories ^:replace [...] instead.")
+                   (do (warn-once "WARNING:"
+                                  ":omit-default-repositories is deprecated;"
+                                  "use :repositories ^:replace [...] instead.")
                        empty-repositories)
                    default-repositories)]
        (setup-map-defaults
@@ -537,9 +554,9 @@
                 :test-selectors {:default (with-meta '(constantly true)
                                             {:displace true})}
                 ;; bump deps in leiningen's own project.clj with these
-                :dependencies '[^:displace [org.clojure/tools.nrepl "0.2.12"
+                :dependencies '[^:displace [nrepl/nrepl "0.6.0"
                                             :exclusions [org.clojure/clojure]]
-                                ^:displace [clojure-complete "0.2.4"
+                                ^:displace [clojure-complete "0.2.5"
                                             :exclusions [org.clojure/clojure]]]
                 :checkout-deps-shares [:source-paths
                                        :test-paths
@@ -674,17 +691,13 @@
                               profiles)]
     (when (and (seq repo-profiles)
                (not (System/getenv "LEIN_SUPPRESS_USER_LEVEL_REPO_WARNINGS")))
-      (warn ":repositories detected in user-level profiles!"
-            (vec (map first repo-profiles)) "\nSee"
-            "https://github.com/technomancy/leiningen/wiki/Repeatability"))))
-
-(alter-var-root #'warn-user-repos memoize)
+      (warn-once ":repositories detected in user-level profiles!"
+                 (vec (map first repo-profiles)) "\nSee"
+                 "https://github.com/technomancy/leiningen/wiki/Repeatability"))))
 
 (defn- warn-user-profile [root profiles]
   (when (and root (contains? profiles :user))
-    (warn "WARNING: user-level profile defined in project files.")))
-
-(alter-var-root #'warn-user-profile memoize)
+    (warn-once "WARNING: user-level profile defined in project files.")))
 
 (defn- system-profiles []
   (let [sys-profile-dir (if (= :windows (utils/get-os))
@@ -771,11 +784,14 @@
 
 (defn- load-hook [hook-name]
   (if-let [hook (try (utils/require-resolve hook-name)
-                     (catch Throwable e
+                     (catch Exception e
                        (utils/error "problem requiring" hook-name "hook")
                        (throw e)))]
-    (try (hook)
-         (catch Throwable e
+    (try (warn-once "Warning: implicit hook found:" hook-name
+                    "\nHooks are deprecated and will be removed"
+                    "in a future version.")
+         (hook)
+         (catch Exception e
            (utils/error "problem activating" hook-name "hook")
            (throw e)))
     (when-not (:optional (meta hook-name))
@@ -939,17 +955,35 @@
     (doseq [path (classpath/get-classpath project)]
       (pomegranate/add-classpath path))))
 
+(defn- load-repository-overrides
+  "Loads any network-centric overrides specified in repository-overrides.clj.
+  This feature allows certain features to be defined outside of the project
+  file, but before the profiles are loaded.  This is necessary because network
+  operations are needed to complete the profile merging themselves and therefore
+  they are not suited to defining network configuration items."
+  [project]
+  (let [overrides (-> (io/file (:root project) "repository-overrides.clj")
+                      (utils/read-file)
+                      (select-keys [:repositories
+                                    :plugin-repositories
+                                    :mirrors
+                                    :certificates
+                                    :local-repo]))]
+    (merge project overrides)))
+
 (defn init-project
   "Initializes a project by loading certificates, plugins, middleware, etc.
 Also merges default profiles."
   ([project default-profiles]
-     (-> (project-with-profiles (doto project
-                                  (load-certificates)
-                                  (init-lein-classpath)
-                                  (load-plugins)))
-         (init-profiles default-profiles)
-         (load-plugins)
-         (activate-middleware)))
+   (-> (load-repository-overrides project)
+       (doto
+             (load-certificates)
+             (init-lein-classpath)
+             (load-plugins))
+       (project-with-profiles)
+       (init-profiles default-profiles)
+       (load-plugins)
+       (activate-middleware)))
   ([project] (init-project project [:default])))
 
 (defn add-profiles
