@@ -13,7 +13,8 @@
               (fn [f]
                 ;; Can't have user-level profiles interfering!
                 (with-redefs [user/profiles (constantly {})
-                              user/credentials (constantly nil)]
+                              user/credentials (constantly nil)
+                              project/warn-once #'project/warn]
                   (f))))
 
 (defn make-project
@@ -43,9 +44,9 @@
                                [stencil/stencil "0.2.0"]
                                [~(symbol "net.3scale" "3scale-api") "3.0.2"]
                                [clj-http/clj-http "3.4.1"]
-                               [org.clojure/tools.nrepl "0.2.12"
+                               [nrepl/nrepl "0.6.0"
                                 :exclusions [[org.clojure/clojure]]]
-                               [clojure-complete/clojure-complete "0.2.4"
+                               [clojure-complete/clojure-complete "0.2.5"
                                 :exclusions [[org.clojure/clojure]]]],
                :twelve 12 ; testing unquote
 
@@ -285,7 +286,7 @@
 (def test-profiles (atom {:qa {:resource-paths ["/etc/myapp"]}
                           :test {:resource-paths ["test/hi"]}
                           :repl {:dependencies
-                                 '[[org.clojure/tools.nrepl "0.2.0-beta6"
+                                 '[[nrepl/nrepl "0.4.5"
                                     :exclusions [org.clojure/clojure]]
                                    [org.thnetos/cd-client "0.3.4"
                                     :exclusions [org.clojure/clojure]]]}
