@@ -5,7 +5,8 @@
         [leiningen.core.user :as user]
         [leiningen.test.helper
          :only [sample-project sample-profile-meta-project
-                managed-deps-project managed-deps-snapshot-project]
+                managed-deps-project managed-deps-snapshot-project
+                with-pom-plugins-project]
          :as lthelper])
   (:require [clojure.data.xml :as xml]
             [leiningen.core.project :as project]
@@ -65,7 +66,7 @@
       (is (= "the git head" (first-in xml [:project :scm :tag]))))))
 
 (deftest test-pom-scm-git
-  (with-redefs [pom/parse-github-url (constantly ["techno" "lein"])
+  (with-redefs [pom/read-git-origin (constantly "git@github.com:techno/lein.git")
                 pom/read-git-head (constantly "the git head")]
     (let [project (with-profile-merged sample-project
                   ^:leaky {:scm {:name "git"
@@ -97,6 +98,36 @@
       (is (= "https://github.com/this-is-not/ignored" (first-in xml [:project :scm :url])))
       (is (= "the git head" (first-in xml [:project :scm :tag]))))))
 
+(deftest test-pom-scm-git-with-https-url
+  (with-redefs [pom/read-git-origin (constantly "https://github.com/techno/lein.git")
+                pom/read-git-head (constantly "the git head")]
+    (let [project (with-profile-merged sample-project
+                  ^:leaky {:scm {:name "git"
+                                 :dir "." ;; so resolve-git-dir looks for lein project .git dir, not the sample
+                                 :connection ":connection is not ignored in :scm :git"
+                                 :url "https://github.com/this-is-not/ignored"}})
+        pom (make-pom project)
+        xml (xml/parse-str pom)]
+      (is (= ":connection is not ignored in :scm :git" (first-in xml [:project :scm :connection])))
+      (is (= "scm:git:ssh://git@github.com/techno/lein.git" (first-in xml [:project :scm :developerConnection])))
+      (is (= "https://github.com/this-is-not/ignored" (first-in xml [:project :scm :url])))
+      (is (= "the git head" (first-in xml [:project :scm :tag]))))))
+
+(deftest test-pom-scm-git-with-non-git-url
+  (with-redefs [pom/read-git-origin (constantly "https://github.com/techno/lein")
+                pom/read-git-head (constantly "the git head")]
+    (let [project (with-profile-merged sample-project
+                  ^:leaky {:scm {:name "git"
+                                 :dir "." ;; so resolve-git-dir looks for lein project .git dir, not the sample
+                                 :connection ":connection is not ignored in :scm :git"
+                                 :url "https://github.com/this-is-not/ignored"}})
+        pom (make-pom project)
+        xml (xml/parse-str pom)]
+      (is (= ":connection is not ignored in :scm :git" (first-in xml [:project :scm :connection])))
+      (is (= "scm:git:ssh://git@github.com/techno/lein.git" (first-in xml [:project :scm :developerConnection])))
+      (is (= "https://github.com/this-is-not/ignored" (first-in xml [:project :scm :url])))
+      (is (= "the git head" (first-in xml [:project :scm :tag]))))))
+
 (deftest test-pom-default-values
   (let [xml (xml/parse-str (make-pom sample-project))]
     (is (= "nomnomnom" (first-in xml [:project :groupId]))
@@ -367,19 +398,19 @@
   (testing "leaky explicit profile"
     (let [p (make-pom (with-profile-merged sample-project
                         ^:leaky
-                        {:dependencies [['org.clojure/tools.nrepl "0.2.2"]]}))
+                        {:dependencies [['nrepl/nrepl "0.4.5"]]}))
           deps (deep-content (xml/parse-str p) [:project :dependencies])
           nrepls (filter #(re-find #"nrepl" (pr-str %)) deps)
           versions (map #(deep-content % [:dependency :version]) nrepls)]
-      (is (= [["0.2.2"]] versions))))
+      (is (= [["0.4.5"]] versions))))
   (testing "pom-scope"
     (let [p (make-pom (with-profile-merged sample-project
                         ^{:pom-scope :test}
-                        {:dependencies [['org.clojure/tools.nrepl "0.2.2"]]}))
+                        {:dependencies [['nrepl/nrepl "0.4.5"]]}))
           deps (deep-content (xml/parse-str p) [:project :dependencies])
           nrepls (filter #(re-find #"nrepl" (pr-str %)) deps)
           versions (map #(deep-content % [:dependency :version]) nrepls)]
-      (is (= [["0.2.2"]] versions)))))
+      (is (= [["0.4.5"]] versions)))))
 
 (deftest test-leaky-profile
   (let [p (make-pom sample-profile-meta-project)
@@ -435,3 +466,50 @@
         (is (= [nil nil nil nil nil "sources" "sources" nil nil]
                (map #(first-in % [:dependency :classifier])
                     (deep-content xml [:project :dependencyManagement :dependencies]))))))))
+
+(deftest test-pom-plugins
+  (let [xml              (xml/parse-str (make-pom with-pom-plugins-project))
+        plugins          (deep-content xml [:project :build :plugins])
+        get-plugin       (fn [re]
+                           (first (filter #(re-find re (pr-str %)) plugins)))
+        simple-plugin    (get-plugin #"simple-plugin")
+        plugin-with-vec  (get-plugin #"with-vec")
+        plugin-with-map  (get-plugin #"with-map")
+        plugin-with-list (get-plugin #"with-list")]
+    (testing "two-parameter version adds maven plugin"
+      (is (= simple-plugin
+             (xml/sexp-as-element
+               [:plugin
+                [:groupId "two.parameter"]
+                [:artifactId "simple-plugin"]
+                [:version "1.0.0"]]))))
+    (testing "vector as third parameter is interpreted as a mapping"
+      (is (= plugin-with-vec
+             (xml/sexp-as-element
+               [:plugin
+                [:groupId "three.parameter"]
+                [:artifactId "with-vec"]
+                [:version "1.0.1"]
+                [:a 3]]))))
+    (testing "hashmap as third parameter is converted to tags"
+      (is (= plugin-with-map
+             (xml/sexp-as-element
+               [:plugin
+                [:groupId "three.parameter"]
+                [:artifactId "with-map"]
+                [:version "1.0.2"]
+                [:a 1]
+                [:b 2]
+                [:c 3]]))))
+    (testing "list as third parameter keeps structure"
+      (is (= plugin-with-list
+             (xml/sexp-as-element
+               [:plugin
+                [:groupId "three.parameter"]
+                [:artifactId "with-list"]
+                [:version "1.0.3"]
+                [:root
+                 [:a 1]
+                 [:b
+                  [:c 2]
+                  [:d 3]]]]))))))
